diff --git a/drivers/clk/clk-composite.c b/drivers/clk/clk-composite.c
index a5626c33d1..484b4a82ba 100644
--- a/drivers/clk/clk-composite.c
+++ b/drivers/clk/clk-composite.c
@@ -18,7 +18,7 @@
 
 static u8 clk_composite_get_parent(struct clk *clk)
 {
-	struct clk_composite *composite = to_clk_composite(clk_dev_binded(clk) ?
+	struct clk_composite *composite = to_clk_composite(clk_dev_bound(clk) ?
 		(struct clk *)dev_get_clk_ptr(clk->dev) : clk);
 	struct clk *mux = composite->mux;
 
@@ -27,7 +27,7 @@ static u8 clk_composite_get_parent(struct clk *clk)
 
 static int clk_composite_set_parent(struct clk *clk, struct clk *parent)
 {
-	struct clk_composite *composite = to_clk_composite(clk_dev_binded(clk) ?
+	struct clk_composite *composite = to_clk_composite(clk_dev_bound(clk) ?
 		(struct clk *)dev_get_clk_ptr(clk->dev) : clk);
 	const struct clk_ops *mux_ops = composite->mux_ops;
 	struct clk *mux = composite->mux;
@@ -37,7 +37,7 @@ static int clk_composite_set_parent(struct clk *clk, struct clk *parent)
 
 static unsigned long clk_composite_recalc_rate(struct clk *clk)
 {
-	struct clk_composite *composite = to_clk_composite(clk_dev_binded(clk) ?
+	struct clk_composite *composite = to_clk_composite(clk_dev_bound(clk) ?
 		(struct clk *)dev_get_clk_ptr(clk->dev) : clk);
 	const struct clk_ops *rate_ops = composite->rate_ops;
 	struct clk *rate = composite->rate;
@@ -47,7 +47,7 @@ static unsigned long clk_composite_recalc_rate(struct clk *clk)
 
 static ulong clk_composite_set_rate(struct clk *clk, unsigned long rate)
 {
-	struct clk_composite *composite = to_clk_composite(clk_dev_binded(clk) ?
+	struct clk_composite *composite = to_clk_composite(clk_dev_bound(clk) ?
 		(struct clk *)dev_get_clk_ptr(clk->dev) : clk);
 	const struct clk_ops *rate_ops = composite->rate_ops;
 	struct clk *clk_rate = composite->rate;
@@ -57,7 +57,7 @@ static ulong clk_composite_set_rate(struct clk *clk, unsigned long rate)
 
 static int clk_composite_enable(struct clk *clk)
 {
-	struct clk_composite *composite = to_clk_composite(clk_dev_binded(clk) ?
+	struct clk_composite *composite = to_clk_composite(clk_dev_bound(clk) ?
 		(struct clk *)dev_get_clk_ptr(clk->dev) : clk);
 	const struct clk_ops *gate_ops = composite->gate_ops;
 	struct clk *gate = composite->gate;
@@ -67,7 +67,7 @@ static int clk_composite_enable(struct clk *clk)
 
 static int clk_composite_disable(struct clk *clk)
 {
-	struct clk_composite *composite = to_clk_composite(clk_dev_binded(clk) ?
+	struct clk_composite *composite = to_clk_composite(clk_dev_bound(clk) ?
 		(struct clk *)dev_get_clk_ptr(clk->dev) : clk);
 	const struct clk_ops *gate_ops = composite->gate_ops;
 	struct clk *gate = composite->gate;
diff --git a/drivers/clk/clk-divider.c b/drivers/clk/clk-divider.c
index 822e09b084..d3c5db0be2 100644
--- a/drivers/clk/clk-divider.c
+++ b/drivers/clk/clk-divider.c
@@ -70,7 +70,7 @@ unsigned long divider_recalc_rate(struct clk *hw, unsigned long parent_rate,
 
 static ulong clk_divider_recalc_rate(struct clk *clk)
 {
-	struct clk_divider *divider = to_clk_divider(clk_dev_binded(clk) ?
+	struct clk_divider *divider = to_clk_divider(clk_dev_bound(clk) ?
 			dev_get_clk_ptr(clk->dev) : clk);
 	unsigned long parent_rate = clk_get_parent_rate(clk);
 	unsigned int val;
@@ -150,7 +150,7 @@ int divider_get_val(unsigned long rate, unsigned long parent_rate,
 
 static ulong clk_divider_set_rate(struct clk *clk, unsigned long rate)
 {
-	struct clk_divider *divider = to_clk_divider(clk_dev_binded(clk) ?
+	struct clk_divider *divider = to_clk_divider(clk_dev_bound(clk) ?
 			dev_get_clk_ptr(clk->dev) : clk);
 	unsigned long parent_rate = clk_get_parent_rate(clk);
 	int value;
diff --git a/drivers/clk/clk-gate.c b/drivers/clk/clk-gate.c
index 70b8794554..905b98a448 100644
--- a/drivers/clk/clk-gate.c
+++ b/drivers/clk/clk-gate.c
@@ -43,7 +43,7 @@
  */
 static void clk_gate_endisable(struct clk *clk, int enable)
 {
-	struct clk_gate *gate = to_clk_gate(clk_dev_binded(clk) ?
+	struct clk_gate *gate = to_clk_gate(clk_dev_bound(clk) ?
 			dev_get_clk_ptr(clk->dev) : clk);
 	int set = gate->flags & CLK_GATE_SET_TO_DISABLE ? 1 : 0;
 	u32 reg;
@@ -86,7 +86,7 @@ static int clk_gate_disable(struct clk *clk)
 
 int clk_gate_is_enabled(struct clk *clk)
 {
-	struct clk_gate *gate = to_clk_gate(clk_dev_binded(clk) ?
+	struct clk_gate *gate = to_clk_gate(clk_dev_bound(clk) ?
 			dev_get_clk_ptr(clk->dev) : clk);
 	u32 reg;
 
diff --git a/drivers/clk/clk-mux.c b/drivers/clk/clk-mux.c
index 5acc0b8cbd..f7d07dc1dc 100644
--- a/drivers/clk/clk-mux.c
+++ b/drivers/clk/clk-mux.c
@@ -35,7 +35,7 @@
 int clk_mux_val_to_index(struct clk *clk, u32 *table, unsigned int flags,
 			 unsigned int val)
 {
-	struct clk_mux *mux = to_clk_mux(clk_dev_binded(clk) ?
+	struct clk_mux *mux = to_clk_mux(clk_dev_bound(clk) ?
 			dev_get_clk_ptr(clk->dev) : clk);
 	int num_parents = mux->num_parents;
 
@@ -79,7 +79,7 @@ unsigned int clk_mux_index_to_val(u32 *table, unsigned int flags, u8 index)
 
 u8 clk_mux_get_parent(struct clk *clk)
 {
-	struct clk_mux *mux = to_clk_mux(clk_dev_binded(clk) ?
+	struct clk_mux *mux = to_clk_mux(clk_dev_bound(clk) ?
 			dev_get_clk_ptr(clk->dev) : clk);
 	u32 val;
 
@@ -97,7 +97,7 @@ u8 clk_mux_get_parent(struct clk *clk)
 static int clk_fetch_parent_index(struct clk *clk,
 				  struct clk *parent)
 {
-	struct clk_mux *mux = to_clk_mux(clk_dev_binded(clk) ?
+	struct clk_mux *mux = to_clk_mux(clk_dev_bound(clk) ?
 			dev_get_clk_ptr(clk->dev) : clk);
 
 	int i;
@@ -115,7 +115,7 @@ static int clk_fetch_parent_index(struct clk *clk,
 
 static int clk_mux_set_parent(struct clk *clk, struct clk *parent)
 {
-	struct clk_mux *mux = to_clk_mux(clk_dev_binded(clk) ?
+	struct clk_mux *mux = to_clk_mux(clk_dev_bound(clk) ?
 			dev_get_clk_ptr(clk->dev) : clk);
 	int index;
 	u32 val;
diff --git a/drivers/clk/clk.c b/drivers/clk/clk.c
index 1cf9987f6c..8ba72ad821 100644
--- a/drivers/clk/clk.c
+++ b/drivers/clk/clk.c
@@ -57,7 +57,7 @@ const char *clk_hw_get_name(const struct clk *hw)
 	return hw->dev->name;
 }
 
-bool clk_dev_binded(struct clk *clk)
+bool clk_dev_bound(struct clk *clk)
 {
 	if (clk->dev && (clk->dev->flags & DM_FLAG_BOUND))
 		return true;
diff --git a/include/clk.h b/include/clk.h
index 3336301815..c5fe3f4567 100644
--- a/include/clk.h
+++ b/include/clk.h
@@ -458,13 +458,13 @@ static inline bool clk_valid(struct clk *clk)
 int clk_get_by_id(ulong id, struct clk **clkp);
 
 /**
  * clk_dev_binded() - Check whether the clk has a device binded
  *
  * @clk		A pointer to the clk
  *
- * @return true on binded, or false on no
+ * @return true when bound, or false otherwise
  */
-bool clk_dev_binded(struct clk *clk);
+bool clk_dev_bound(struct clk *clk);
 #endif
 
 #define clk_prepare_enable(clk) clk_enable(clk)
@@ -458,13 +458,13 @@ static inline bool clk_valid(struct clk *clk)
 
 /**
- * clk_dev_binded() - Check whether the clk has a device binded
+ * clk_dev_bound() - Check whether the clk has a device bound
  *
  * @clk		A pointer to the clk
